StepOutcome

Enum StepOutcome 

#[non_exhaustive]
pub enum StepOutcome { Accepted, RejectedProposal, NoProposal, }
Outcome of a completed Metropolis-Hastings step.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Accepted

A concrete proposal was accepted and committed.



RejectedProposal

A concrete proposal was produced and then rejected by the Metropolis-Hastings acceptance draw.



NoProposal

No concrete proposal was available, so the step was an ordinary self-loop without a Metropolis-Hastings acceptance draw.

Implementations

Source

impl StepOutcome

pub const fn is_accepted(self) -> bool

Whether this outcome accepted and committed a concrete proposal.

use markov_chain_monte_carlo::prelude::delayed::StepOutcome;

assert!(StepOutcome::Accepted.is_accepted());
assert!(!StepOutcome::RejectedProposal.is_accepted());
assert!(!StepOutcome::NoProposal.is_accepted());
pub const fn has_proposal(self) -> bool

Whether this outcome includes a concrete proposal.

use markov_chain_monte_carlo::prelude::delayed::StepOutcome;

assert!(StepOutcome::Accepted.has_proposal());
assert!(StepOutcome::RejectedProposal.has_proposal());
assert!(!StepOutcome::NoProposal.has_proposal());