#[non_exhaustive]pub enum BackendMutationOperation {
SetSimplexDataByKey,
SetVertexDataByKey,
SetVertexData,
SubdivideFace,
RemoveVertex,
FlipEdge,
}Expand description
Backend mutation operation that failed while editing a CDT triangulation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SetSimplexDataByKey
Write simplex payload by backend simplex key.
SetVertexDataByKey
Write vertex payload by backend vertex key.
SetVertexData
Write vertex payload through a vertex handle.
SubdivideFace
Subdivide a face as part of a local move.
RemoveVertex
Remove a vertex as part of a local move.
FlipEdge
Flip an edge as part of a local move.