GenerationParameterIssue

Enum GenerationParameterIssue 

#[non_exhaustive]
pub enum GenerationParameterIssue { InvalidCoordinateRange, InvalidToroidalDomain, NonFiniteVertexCoordinate, InsufficientVertexCount, InsufficientVerticesPerSlice, InsufficientNumberOfTimeSlices, NonPositiveSliceCount, EmptyVolumeProfile, VolumeProfileLengthOverflow, InsufficientVerticesInVolumeProfileSlice, VertexCountOverflow, SimplexCountOverflow, }
Identifies the issue category for invalid triangulation generation parameters.

Use this with CdtError::InvalidGenerationParameters when a constructor rejects input before attempting triangulation.

Examples

use causal_triangulations::prelude::errors::{CdtError, GenerationParameterIssue};
use causal_triangulations::prelude::triangulation::CdtTriangulation;
use std::assert_matches;

let err = CdtTriangulation::from_random_points(2, 2, 2)
    .expect_err("fewer than three vertices cannot form a triangulation");

assert_matches!(
    err,
    CdtError::InvalidGenerationParameters {
        issue: GenerationParameterIssue::InsufficientVertexCount,
        ..
    }
);

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidCoordinateRange

Coordinate range has invalid ordering or bounds.



InvalidToroidalDomain

Toroidal domain extents are invalid.



NonFiniteVertexCoordinate

A supplied vertex coordinate is NaN or infinite.



InsufficientVertexCount

Total vertex count is below the constructor minimum.



InsufficientVerticesPerSlice

Per-slice vertex count is below the constructor minimum.



InsufficientNumberOfTimeSlices

Number of time slices is below the topology minimum.



NonPositiveSliceCount

A slice count was zero where at least one slice is required.



EmptyVolumeProfile

Explicit volume profile has no slices.



VolumeProfileLengthOverflow

Explicit volume profile length cannot fit in supported counters.



InsufficientVerticesInVolumeProfileSlice

A volume-profile slice has too few vertices.



VertexCountOverflow

Total vertex count cannot fit in supported counters.



SimplexCountOverflow

Simplex count cannot fit in supported counters.