#[non_exhaustive]pub enum StepOutcome {
Accepted,
RejectedProposal,
NoProposal,
}Expand description
Outcome of a completed Metropolis-Hastings step.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Accepted
A concrete proposal was accepted and committed.
RejectedProposal
A concrete proposal was produced and then rejected by the Metropolis-Hastings acceptance draw.
NoProposal
No concrete proposal was available, so the step was an ordinary self-loop without a Metropolis-Hastings acceptance draw.
Implementations
Sourceimpl StepOutcome
impl StepOutcome
Sourcepub const fn is_accepted(self) -> bool
pub const fn is_accepted(self) -> bool
Whether this outcome accepted and committed a concrete proposal.
use markov_chain_monte_carlo::prelude::delayed::StepOutcome;
assert!(StepOutcome::Accepted.is_accepted());
assert!(!StepOutcome::RejectedProposal.is_accepted());
assert!(!StepOutcome::NoProposal.is_accepted());Sourcepub const fn has_proposal(self) -> bool
pub const fn has_proposal(self) -> bool
Whether this outcome includes a concrete proposal.
use markov_chain_monte_carlo::prelude::delayed::StepOutcome;
assert!(StepOutcome::Accepted.has_proposal());
assert!(StepOutcome::RejectedProposal.has_proposal());
assert!(!StepOutcome::NoProposal.has_proposal());Trait Implementations
Sourceimpl Clone for StepOutcome
impl Clone for StepOutcome
Sourcefn clone(&self) -> StepOutcome
fn clone(&self) -> StepOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StepOutcome
impl Debug for StepOutcome
Sourceimpl From<StepOutcome> for TraceStepOutcome
impl From<StepOutcome> for TraceStepOutcome
Sourcefn from(outcome: StepOutcome) -> TraceStepOutcome
fn from(outcome: StepOutcome) -> TraceStepOutcome
Converts to this type from the input type.
Sourceimpl PartialEq for StepOutcome
impl PartialEq for StepOutcome
Sourcefn eq(&self, other: &StepOutcome) -> bool
fn eq(&self, other: &StepOutcome) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for StepOutcome
impl Eq for StepOutcome
impl StructuralPartialEq for StepOutcome